#' Convert a string to a vector of characters
#'
#' See [strex::str_to_vec()].
#'
#' @inheritParams strex::str_to_vec
#'
#' @export
str_to_vec <- strex::str_to_vec

#' @rdname str_to_vec
#' @export
to_vec <- str_to_vec
